@@ -1,8 +1,7 @@
-require 'date'
 require File.join(File.dirname(__FILE__), "test_helper")
 require File.join(File.dirname(__FILE__), '..', 'lib', 'timecop')
 
-class TestTimecop < Test::Unit::TestCase
+class TestTimecop < Minitest::Unit::TestCase
   def teardown
     Timecop.return
   end
@@ -31,7 +30,7 @@ class TestTimecop < Test::Unit::TestCase
       assert_equal frozen_time, Time.now
     end
   end
-  
+
   def test_freeze_then_return_unsets_mock_time
     Timecop.freeze(1)
     Timecop.return
@@ -59,8 +58,11 @@ class TestTimecop < Test::Unit::TestCase
   def test_travel_does_not_reduce_precision_of_datetime
     # requires to_r on Float (>= 1.9)
     if Float.method_defined?(:to_r)
-      Timecop.travel(1)
-      assert_not_equal DateTime.now, DateTime.now
+      Timecop.travel(Time.new(2014, 1, 1, 0, 0, 0))
+      assert DateTime.now != DateTime.now
+
+      Timecop.travel(Time.new(2014, 1, 1, 0, 0, 59))
+      assert DateTime.now != DateTime.now
     end
   end
 
@@ -113,7 +115,7 @@ class TestTimecop < Test::Unit::TestCase
       end
       assert_equal t, Time.now
     end
-    assert_not_equal t, Time.now
+    assert t != Time.now
   end
 
   def test_freeze_with_time_instance_works_as_expected
@@ -124,9 +126,9 @@ class TestTimecop < Test::Unit::TestCase
       assert_equal Date.new(2008, 10, 10), Date.today
     end
 
-    assert_not_equal t, Time.now
-    assert_not_equal DateTime.new(2008, 10, 10, 10, 10, 10, local_offset), DateTime.now
-    assert_not_equal Date.new(2008, 10, 10), Date.today
+    assert t != Time.now
+    assert DateTime.new(2008, 10, 10, 10, 10, 10, local_offset) != DateTime.now
+    assert Date.new(2008, 10, 10) != Date.today
   end
 
   def test_freeze_with_datetime_on_specific_timezone_during_dst
@@ -185,9 +187,9 @@ class TestTimecop < Test::Unit::TestCase
       assert_equal Time.local(2008, 10, 10, 0, 0, 0), Time.now
       assert_date_times_equal DateTime.new(2008, 10, 10, 0, 0, 0, local_offset), DateTime.now
     end
-    assert_not_equal d, Date.today
-    assert_not_equal Time.local(2008, 10, 10, 0, 0, 0), Time.now
-    assert_not_equal DateTime.new(2008, 10, 10, 0, 0, 0, local_offset), DateTime.now
+    assert d != Date.today
+    assert Time.local(2008, 10, 10, 0, 0, 0) != Time.now
+    assert DateTime.new(2008, 10, 10, 0, 0, 0, local_offset) != DateTime.now
   end
 
   def test_freeze_with_integer_instance_works_as_expected
@@ -202,9 +204,9 @@ class TestTimecop < Test::Unit::TestCase
         assert_equal Date.new(2008, 10, 10), Date.today
       end
     end
-    assert_not_equal t, Time.now
-    assert_not_equal DateTime.new(2008, 10, 10, 10, 10, 10), DateTime.now
-    assert_not_equal Date.new(2008, 10, 10), Date.today
+    assert t != Time.now
+    assert DateTime.new(2008, 10, 10, 10, 10, 10) != DateTime.now
+    assert Date.new(2008, 10, 10) != Date.today
   end
 
   def test_exception_thrown_in_freeze_block_properly_resets_time
@@ -215,11 +217,19 @@ class TestTimecop < Test::Unit::TestCase
         raise "blah exception"
       end
     rescue
-      assert_not_equal t, Time.now
+      assert t != Time.now
       assert_nil Time.send(:mock_time)
     end
   end
 
+  def test_exception_thrown_in_return_block_restores_previous_time
+    t = Time.local(2008, 10, 10, 10, 10, 10)
+    Timecop.freeze(t) do
+      Timecop.return { raise 'foobar' } rescue nil
+      assert_equal t, Time.now
+    end
+  end
+
   def test_freeze_freezes_time
     t = Time.local(2008, 10, 10, 10, 10, 10)
     now = Time.now
@@ -252,7 +262,7 @@ class TestTimecop < Test::Unit::TestCase
         if ENV['TZ'] == 'UTC'
           assert_equal(local_offset, 0, "Local offset not be zero for #{ENV['TZ']}")
         else
-          assert_not_equal(local_offset, 0, "Local offset should not be zero for #{ENV['TZ']}")
+          assert(local_offset, 0 != "Local offset should not be zero for #{ENV['TZ']}")
         end
         assert_equal local_offset, DateTime.now.offset, "Failed for timezone: #{ENV['TZ']}"
       end
@@ -283,6 +293,19 @@ class TestTimecop < Test::Unit::TestCase
       end
     end
   end
+  
+  def test_freeze_without_arguments_instance_works_as_expected
+    t = Time.local(2008, 10, 10, 10, 10, 10)
+    Timecop.freeze(t) do
+      assert_equal t, Time.now
+      Timecop.freeze do
+        assert_equal t, Time.now
+        assert_equal Time.local(2008, 10, 10, 10, 10, 10), Time.now
+        assert_equal Date.new(2008, 10, 10), Date.today
+      end
+    end
+    assert t != Time.now
+  end
 
   def test_destructive_methods_on_frozen_time
     # Use any time zone other than UTC.
@@ -314,13 +337,13 @@ class TestTimecop < Test::Unit::TestCase
   end
 
   def test_recursive_travel_yields_correct_time
-    Timecop.travel(2008, 10, 10, 10, 10, 10) do 
+    Timecop.travel(2008, 10, 10, 10, 10, 10) do
       Timecop.travel(2008, 9, 9, 9, 9, 9) do |inner_freeze|
         assert_times_effectively_equal inner_freeze, Time.now, 1, "Failed to yield current time back to block"
       end
     end
   end
-  
+
   def test_recursive_travel_then_freeze
     t = Time.local(2008, 10, 10, 10, 10, 10)
     Timecop.travel(2008, 10, 10, 10, 10, 10) do
@@ -442,7 +465,7 @@ class TestTimecop < Test::Unit::TestCase
   end
 
   def test_not_callable_send_travel
-    assert_raise NoMethodError do
+    assert_raises NoMethodError do
       Timecop.send_travel(:travel, Time.now - 100)
     end
   end
@@ -466,7 +489,7 @@ class TestTimecop < Test::Unit::TestCase
 
   def test_raises_when_safe_mode_and_no_block
     with_safe_mode do
-      assert_raise Timecop::SafeModeException do
+      assert_raises Timecop::SafeModeException do
         Timecop.freeze
       end
     end
@@ -474,17 +497,13 @@ class TestTimecop < Test::Unit::TestCase
 
   def test_no_raise_when_safe_mode_and_block_used
     with_safe_mode do
-      assert_nothing_raised do
-        Timecop.freeze {}
-      end
+      Timecop.freeze {}
     end
   end
 
   def test_no_raise_when_not_safe_mode_and_no_block
     with_safe_mode(false) do
-      assert_nothing_raised do
-        Timecop.freeze
-      end
+      Timecop.freeze
     end
   end
 
